<?php

/*
 * 送信時にflagを送信させる
 *
 *
 */


//関数

require("../lib/pdo_search.php");
	
//本体

		$name = $_GET['name'];

		$query = "SELECT * FROM Version0_db WHERE book_name  LIKE \"%".$name."%\"   ";


		$array = pdo_search($query);

		if(isset($array)) {

			$flag = "true";
			$count = count($array);
		} else {
			$flag = "false";

		}













require("../lib/smarty.php");

if($flag == "true") {
	$smarty->assign("book",$array[0]);
	$smarty->assign("count",$count);

}

$smarty->assign("flag",$flag);
$smarty->assign("title","本の詳細"); //headerのtitle

$smarty->display("book_info.tpl");


?> 

